@@ -1,4 +1,4 @@
-__version__ = "0.2.1"
+__version__ = "0.2.2"
 __author__ = "TensorCircuit Authors"
 __creator__ = "refraction-ray"
 
@@ -6,6 +6,9 @@ from .cons import (
     set_backend,
     set_dtype,
     set_contractor,
+    get_backend,
+    get_dtype,
+    get_contractor,
     set_function_backend,
     set_function_dtype,
     set_function_contractor,
