@@ -197,6 +197,7 @@ class JaxBackend(jax_backend.JaxBackend):  # type: ignore
                 "backend or install Jax."
             )
         from jax.experimental import sparse
+        import jax.scipy
 
         try:
             import optax
@@ -310,6 +311,9 @@ class JaxBackend(jax_backend.JaxBackend):  # type: ignore
     def imag(self, a: Tensor) -> Tensor:
         return jnp.imag(a)
 
+    def dtype(self, a: Tensor) -> str:
+        return a.dtype.__str__()  # type: ignore
+
     def cast(self, a: Tensor, dtype: str) -> Tensor:
         if isinstance(dtype, str):
             return a.astype(getattr(jnp, dtype))
@@ -395,12 +399,22 @@ class JaxBackend(jax_backend.JaxBackend):  # type: ignore
     def tree_map(self, f: Callable[..., Any], *pytrees: Any) -> Any:
         return libjax.tree_map(f, *pytrees)
 
-    def tree_flatten(self: Any, pytree: Any) -> Tuple[Any, Any]:
+    def tree_flatten(self, pytree: Any) -> Tuple[Any, Any]:
         return libjax.tree_flatten(pytree)  # type: ignore
 
-    def tree_unflatten(self: Any, treedef: Any, leaves: Any) -> Any:
+    def tree_unflatten(self, treedef: Any, leaves: Any) -> Any:
         return libjax.tree_unflatten(treedef, leaves)
 
+    def from_dlpack(self, a: Any) -> Tensor:
+        import jax.dlpack
+
+        return jax.dlpack.from_dlpack(a)  # type: ignore
+
+    def to_dlpack(self, a: Tensor) -> Any:
+        import jax.dlpack
+
+        return jax.dlpack.to_dlpack(a)  # type: ignore
+
     def set_random_state(
         self, seed: Optional[Union[int, PRNGKeyArray]] = None, get_only: bool = False
     ) -> Any:
