@@ -283,8 +283,11 @@ class PyTorchBackend(pytorch_backend.PyTorchBackend):  # type: ignore
         return torchlib.kron(a, b)
 
     def numpy(self, a: Tensor) -> Tensor:
+        a = a.cpu()
         if a.is_conj():
             return a.resolve_conj().numpy()
+        if a.requires_grad:
+            return a.detach().numpy()
         return a.numpy()
 
     def i(self, dtype: Any = None) -> Tensor:
@@ -308,6 +311,9 @@ class PyTorchBackend(pytorch_backend.PyTorchBackend):  # type: ignore
             pass
         return a
 
+    def dtype(self, a: Tensor) -> str:
+        return a.dtype.__str__().split(".")[-1]  # type: ignore
+
     def stack(self, a: Sequence[Tensor], axis: int = 0) -> Tensor:
         return torchlib.stack(a, dim=axis)
 
@@ -396,8 +402,16 @@ class PyTorchBackend(pytorch_backend.PyTorchBackend):  # type: ignore
         return torchlib.flip(a, dims=(-1,))
 
     def tree_map(self, f: Callable[..., Any], *pytrees: Any) -> Any:
-        # TODO(@refraction-ray): torch not support multiple pytree args
-        return torchlib.utils._pytree.tree_map(f, *pytrees)
+        # torch native tree_map not support multiple pytree args
+        # return torchlib.utils._pytree.tree_map(f, *pytrees)
+        args = []
+        for pytree in pytrees:
+            flat_args, spec = self.tree_flatten(pytree)
+            args.append(flat_args)
+        res = [
+            f(*[args[i][k] for i in range(len(pytrees))]) for k in range(len(flat_args))
+        ]
+        return self.tree_unflatten(spec, res)
 
     def tree_flatten(self: Any, pytree: Any) -> Tuple[Any, Any]:
         return torchlib.utils._pytree.tree_flatten(pytree)  # type: ignore
@@ -405,6 +419,12 @@ class PyTorchBackend(pytorch_backend.PyTorchBackend):  # type: ignore
     def tree_unflatten(self: Any, treedef: Any, leaves: Any) -> Any:
         return torchlib.utils._pytree.tree_unflatten(leaves, treedef)
 
+    def from_dlpack(self, a: Any) -> Tensor:
+        return torchlib.utils.dlpack.from_dlpack(a)
+
+    def to_dlpack(self, a: Tensor) -> Any:
+        return torchlib.utils.dlpack.to_dlpack(a)
+
     def cond(
         self,
         pred: bool,
