@@ -274,6 +274,15 @@ def test_backend_methods_2(backend):
         tc.backend.arange(1, 5, 2),
         np.array([1, 3]),
     )
+    assert tc.backend.dtype(tc.backend.ones([])) == "complex64"
+
+
+@pytest.mark.parametrize("backend", [lf("tfb"), lf("jaxb"), lf("torchb")])
+def test_dlpack(backend):
+    a = tc.backend.ones([2, 2], dtype="float64")
+    cap = tc.backend.to_dlpack(a)
+    a1 = tc.backend.from_dlpack(cap)
+    np.testing.assert_allclose(a, a1, atol=1e-5)
 
 
 @pytest.mark.parametrize("backend", [lf("npb"), lf("tfb"), lf("jaxb"), lf("torchb")])
@@ -293,7 +302,7 @@ def test_arg_cmp(backend):
     )
 
 
-@pytest.mark.parametrize("backend", [lf("npb"), lf("tfb"), lf("jaxb")])
+@pytest.mark.parametrize("backend", [lf("npb"), lf("tfb"), lf("jaxb"), lf("torchb")])
 def test_tree_map(backend):
     def f(a, b):
         return a + b
@@ -303,6 +312,16 @@ def test_tree_map(backend):
     )
     assert np.allclose(r["a"], 3 * np.ones([2]), atol=1e-4)
 
+    def _add(a, b):
+        return a + b
+
+    ans = tc.backend.tree_map(
+        _add,
+        {"a": tc.backend.ones([2]), "b": tc.backend.ones([3])},
+        {"a": tc.backend.ones([2]), "b": tc.backend.ones([3])},
+    )
+    np.testing.assert_allclose(ans["a"], 2 * np.ones([2]))
+
 
 @pytest.mark.parametrize("backend", [lf("npb"), lf("tfb"), lf("jaxb")])
 def test_backend_randoms(backend):
